@@ -1,11 +1,12 @@
 package DataFlow::Meta;
 
-#ABSTRACT: A piece of information metadata
-
 use strict;
 use warnings;
 
-our $VERSION = '0.91.07';    # VERSION
+# ABSTRACT: A piece of information metadata
+# ENCODING: utf8
+
+our $VERSION = '0.91.08';    # VERSION
 
 use Moose;
 use DateTime;
@@ -18,18 +19,21 @@ has 'original'     => ( is => 'rw', isa => 'Str', );
 has 'restrictions' => ( is => 'rw', isa => 'Str', );
 
 __PACKAGE__->meta->make_immutable;
+no Moose;
 
 1;
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 DataFlow::Meta - A piece of information metadata
 
 =head1 VERSION
 
-version 0.91.07
+version 0.91.08
 
 =head1 AUTHOR
 
