@@ -1,15 +1,16 @@
 package DataFlow::Node;
 
-#ABSTRACT: A generic processing node in a data flow
-
 use strict;
 use warnings;
 
-our $VERSION = '0.91.07';    # VERSION
+# ABSTRACT: A generic processing node in a data flow
+# ENCODING: utf8
+
+our $VERSION = '0.91.08';    # VERSION
 
 use Moose;
 
-use Scalar::Util qw/blessed reftype/;
+use Scalar::Util qw/blessed reftype looks_like_number/;
 use Queue::Base;
 
 has 'name' => (
@@ -156,13 +157,26 @@ before '_add_output' => sub {
 
 sub output {
     my $self = shift;
-    if ( $self->auto_process ) {
-        $self->process_input if $self->outputq->empty;
+    my $num  = shift;
+
+    $self->process_input if ( $self->outputq->empty && $self->auto_process );
+
+    return $self->outputq->remove unless wantarray;
+
+    if ( defined($num) ) {
+        $self->confess(qq{"$num" does not look like a number})
+          unless looks_like_number($num);
+        $self->confess(qq{"$num" must be a positive integer}) if $num < 1;
+        if ( $self->auto_process ) {
+            while ( $self->outputq->size < $num && $self->has_input ) {
+                $self->process_input;
+            }
+        }
+        return $self->outputq->remove($num);
     }
 
     #use Data::Dumper; warn 'output self = ' .Dumper($self);
-    return ( $self->_dequeue_output ) if wantarray;
-    return scalar $self->_dequeue_output;
+    return $self->outputq->remove_all;
 }
 
 sub flush {
@@ -313,18 +327,21 @@ sub _handle_code_ref {
 }
 
 __PACKAGE__->meta->make_immutable;
+no Moose;
 
 1;
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 DataFlow::Node - A generic processing node in a data flow
 
 =head1 VERSION
 
-version 0.91.07
+version 0.91.08
 
 =head1 SYNOPSIS
 
