@@ -1,71 +1,94 @@
 package DataFlow::Node::CSV;
 
-#ABSTRACT: A CSV converting node
-
 use strict;
 use warnings;
 
-our $VERSION = '0.91.07';    # VERSION
+# ABSTRACT: A CSV converting node
+# ENCODING: utf8
+
+our $VERSION = '0.91.08';    # VERSION
 
 use Moose;
 extends 'DataFlow::Node';
 
-use Carp;
+use Moose::Util::TypeConstraints;
 use Text::CSV;
 
-has 'header' => (
+has 'headers' => (
     'is'        => 'ro',
     'isa'       => 'ArrayRef[Str]',
-    'predicate' => 'has_header',
+    'predicate' => 'have_headers',
 );
 
-has 'inject_header' => (
+has '_header_unused' => (
     'is'      => 'ro',
     'isa'     => 'Bool',
-    'default' => 0,
+    'default' => 1,
+    'clearer' => '_use_header',
+);
+
+enum '_direction_type' => [qw/FROM_CSV TO_CSV/];
+
+has 'direction' => (
+    'is'       => 'ro',
+    'isa'      => '_direction_type',
+    'required' => 1,
 );
 
 has 'text_csv_opts' => (
-    'is'        => 'ro',
-    'isa'       => 'HashRef',
-    'predicate' => 'has_text_csv_opts',
+    'is'  => 'ro',
+    'isa' => 'HashRef',
 );
 
 has 'csv' => (
     'is'      => 'ro',
     'isa'     => 'Text::CSV',
-    'lazy'    => 1,
     'default' => sub {
         my $self = shift;
 
         my $make_csv = sub {
-            return Text::CSV->new(
-                $self->has_text_csv_opts ? $self->text_csv_opts : undef );
+            return Text::CSV->new( $self->text_csv_opts );
         };
-        return $make_csv->() unless $self->inject_header;
+        return $make_csv->() unless $self->have_headers;
 
-        croak 'Thou hast requested to inject headers but,'
-          . 'alas, no header has been provided'
-          unless ( $self->has_header );
+        # use headers
+        if ( $self->direction eq 'TO_CSV' ) {
+            $self->input( $self->headers );
+        }
 
-        $self->_add_output( $self->deref ? @{ $self->header } : $self->header );
         return $make_csv->();
     },
 );
 
-has '+process_item' => (
-    'default' => sub {
-        return sub {
-            my ( $self, $data ) = @_;
-            return $data unless ref($data) eq 'ARRAY';
+before 'process_input' => sub {
+    my $self = shift;
+    return unless $self->direction eq 'TO_CSV';
+    $self->add_output( $self->headers );
+    $self->_use_header;
+};
 
-            $self->csv->combine( @{$data} );
-            return $self->csv->string;
-          }
+sub _to_csv {
+    my ( $self, $data ) = @_;
+    $self->csv->combine( @{$data} );
+    return $self->csv->string;
+}
+
+sub _from_csv {
+    my ( $self, $csvline ) = @_;
+    $self->csv->parse($csvline);
+    return [ $self->csv->fields ];
+}
+
+has '+process_item' => (
+    'lazy'    => 1,
+    'default' => sub {
+        return \&_to_csv if shift->direction eq 'TO_CSV';
+        return \&_from_csv;
     }
 );
 
 __PACKAGE__->meta->make_immutable;
+no Moose;
 
 1;
 
@@ -73,13 +96,15 @@ __END__
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 DataFlow::Node::CSV - A CSV converting node
 
 =head1 VERSION
 
-version 0.91.07
+version 0.91.08
 
 =head1 AUTHOR
 
