@@ -1,11 +1,12 @@
 package DataFlow::Node::Dumper;
 
-#ABSTRACT: A debugging node that will dump data to STDERR
-
 use strict;
 use warnings;
 
-our $VERSION = '0.91.07';    # VERSION
+# ABSTRACT: A debugging node that will dump data to STDERR
+# ENCODING: utf8
+
+our $VERSION = '0.91.08';    # VERSION
 
 use Moose;
 extends 'DataFlow::Node';
@@ -23,18 +24,21 @@ has '+process_item' => (
 );
 
 __PACKAGE__->meta->make_immutable;
+no Moose;
 
 1;
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 DataFlow::Node::Dumper - A debugging node that will dump data to STDERR
 
 =head1 VERSION
 
-version 0.91.07
+version 0.91.08
 
 =head1 SYNOPSIS
 
