@@ -1,11 +1,12 @@
 package DataFlow::Node::HTMLFilter;
 
-#ABSTRACT: A HTML filtering node
-
 use strict;
 use warnings;
 
-our $VERSION = '0.91.07';    # VERSION
+# ABSTRACT: A HTML filtering node
+# ENCODING: utf8
+
+our $VERSION = '0.91.08';    # VERSION
 
 use Moose;
 extends 'DataFlow::Node';
@@ -65,18 +66,21 @@ has '+process_item' => (
 );
 
 __PACKAGE__->meta->make_immutable;
+no Moose;
 
 1;
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 DataFlow::Node::HTMLFilter - A HTML filtering node
 
 =head1 VERSION
 
-version 0.91.07
+version 0.91.08
 
 =head1 SYNOPSIS
 
