@@ -1,11 +1,12 @@
 package DataFlow::Node::MultiPageURLGenerator;
 
-#ABSTRACT: A node that generates multi-paged URL lists
-
 use strict;
 use warnings;
 
-our $VERSION = '0.91.07';    # VERSION
+# ABSTRACT: A node that generates multi-paged URL lists
+# ENCODING: utf8
+
+our $VERSION = '0.91.08';    # VERSION
 
 use Moose;
 extends 'DataFlow::Node';
@@ -87,6 +88,7 @@ has '+process_item' => (
 );
 
 __PACKAGE__->meta->make_immutable;
+no Moose;
 
 1;
 
@@ -94,13 +96,15 @@ __END__
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 DataFlow::Node::MultiPageURLGenerator - A node that generates multi-paged URL lists
 
 =head1 VERSION
 
-version 0.91.07
+version 0.91.08
 
 =head1 AUTHOR
 
