@@ -1,11 +1,12 @@
 package DataFlow::Node::NOP;
 
-#ABSTRACT: A No-Op node, input data is passed unmodified to the output
-
 use strict;
 use warnings;
 
-our $VERSION = '0.91.07';    # VERSION
+# ABSTRACT: A No-Op node, input data is passed unmodified to the output
+# ENCODING: utf8
+
+our $VERSION = '0.91.08';    # VERSION
 
 use Moose;
 extends 'DataFlow::Node';
@@ -17,18 +18,21 @@ has '+process_item' => (
 );
 
 __PACKAGE__->meta->make_immutable;
+no Moose;
 
 1;
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 DataFlow::Node::NOP - A No-Op node, input data is passed unmodified to the output
 
 =head1 VERSION
 
-version 0.91.07
+version 0.91.08
 
 =head1 SYNOPSIS
 
