@@ -1,11 +1,12 @@
 package DataFlow::Node::URLRetriever::Get;
 
-#ABSTRACT: A HTTP Getter
-
 use strict;
 use warnings;
 
-our $VERSION = '0.91.07';    # VERSION
+# ABSTRACT: A HTTP Getter
+# ENCODING: utf8
+
+our $VERSION = '0.91.08';    # VERSION
 
 use Moose;
 
@@ -103,19 +104,23 @@ sub post {
     return;
 }
 
+no Moose;
+
 1;
 
 __END__
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 DataFlow::Node::URLRetriever::Get - A HTTP Getter
 
 =head1 VERSION
 
-version 0.91.07
+version 0.91.08
 
 =head2 get URL
 
